Produces a summary of a fitted vdra linear regression model.
## S3 method for class 'vdralinear'
# S3 method for vdralinear
summary(object, ...)a vdralinear object.
futher argumetns passed to or from other methods.
Returns an object of class summary.vdralinear. Objects of this class have a method for the function print. The following components must be included in summary.vdralinear object.
logical value. If FALSE, then there was an error processing the data. if TRUE, there were no errors.
a vector which indicates the party from which each covariate came.
the vector of coefficients. If the model is over-determined, there will be missing values in the vector corresponding to the redudant columns model matrix.
the vector of the standard error of the coefficients.
the t-values of the coefficietns.
the p-values of the coefficients.
residual standard error.
r squared.
adjusted r squared.
the F-statistic for the linear regression.
the numerator degrees of freedom for the F-statistic.
the denominator degrees of freedom for the F-statistic.
the p-value of the F-statistic for the linear regression.
# NOT RUN {
summary(vdra_fit_linear_A)
# }
Run the code above in your browser using DataLab